@@ -1,28 +1,20 @@
 /*
     This file is part of the KDE games library
-    Copyright (C) 2001 Burkhard Lehner (Burkhard.Lehner@gmx.de)
+    SPDX-FileCopyrightText: 2001 Burkhard Lehner <Burkhard.Lehner@gmx.de>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License version 2 as published by the Free Software Foundation.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-only
 */
 
 #ifndef __KMESSAGESERVER_H__
 #define __KMESSAGESERVER_H__
 
+// own
+#include "libkdegamesprivate_export.h"
+// Qt
 #include <QObject>
 #include <QString>
-#include "libkdegamesprivate_export.h"
+// Std
+#include <memory>
 
 class KMessageIO;
 class KMessageServerPrivate;
@@ -208,7 +200,7 @@ public:
     /**
      * Create a KGameNetwork object
      **/
-    explicit KMessageServer(quint16 cookie = 42, QObject* parent = 0);
+    explicit KMessageServer(quint16 cookie = 42, QObject* parent = nullptr);
 
     ~KMessageServer();
 
@@ -459,7 +451,7 @@ protected:
     quint32 uniqueClientNumber() const;
 
 private:
-    KMessageServerPrivate* d;
+    std::unique_ptr<KMessageServerPrivate> const d;
 };
 
 
